toolchain-utils: Fix hyphen/underscore issue for nightly tests.

The recipe builders use hyphens, while gsutil uses underscores.  We
had a fix in place for this for veyron_minnie; this updates the fix for
veyron_tiger.

BUG=None
TEST=None

Change-Id: Ide32264e1cbbe29afc8ca2cd44e449b56f91a2c1
Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/third_party/toolchain-utils/+/2585646
Auto-Submit: Caroline Tice <cmtice@chromium.org>
Reviewed-by: Manoj Gupta <manojgupta@chromium.org>
Commit-Queue: Caroline Tice <cmtice@chromium.org>
Tested-by: Caroline Tice <cmtice@chromium.org>
diff --git a/buildbot_test_toolchains.py b/buildbot_test_toolchains.py
index 4898796..b546894 100755
--- a/buildbot_test_toolchains.py
+++ b/buildbot_test_toolchains.py
@@ -71,7 +71,7 @@
 }
 RECIPE_IMAGE_RE = RECIPE_IMAGE_FS.format(**RECIPE_IMAGE_RE_GROUPS)
 
-TELEMETRY_AQUARIUM_UNSUPPORTED = ['bob', 'elm', 'veyron_minnie']
+TELEMETRY_AQUARIUM_UNSUPPORTED = ['bob', 'elm', 'veyron_tiger']
 
 
 class ToolchainComparator(object):
@@ -124,9 +124,9 @@
     """
     # For board names with underscores, we need to fix the trybot image name
     # to replace the hyphen (for the recipe builder) with the underscore.
-    # Currently the only such board we use is 'veyron_minnie'.
-    if trybot_image.find('veyron-minnie') != -1:
-      trybot_image = trybot_image.replace('veyron-minnie', 'veyron_minnie')
+    # Currently the only such board we use is 'veyron_tiger'.
+    if trybot_image.find('veyron-tiger') != -1:
+      trybot_image = trybot_image.replace('veyron-tiger', 'veyron_tiger')
     # We need to filter out -tryjob in the trybot_image.
     if self._recipe:
       trybot = re.sub('-llvm-next-nightly', '-release', trybot_image)